# Governance

This Project belongs to the *NiPreps* Community, and its governance model abides by the [`PROJECT-CHARTER.md`](https://github.com/nipreps/GOVERNANCE/blob/main/org-docs/PROJECT-CHARTER.md) document.
